@@ -1,5 +1,6 @@
 from collections import defaultdict
 from curses import tigetstr, setupterm, tparm
+import os
 from os import isatty
 from traceback import format_list, extract_tb, format_exception_only
 
@@ -94,9 +95,13 @@ class ProgressiveResult(TextTestResult):
                     if address:  # None if no such callable found. No sense
                                  # trying to find the test frame if there's no
                                  # such thing.
-                        file, line = frame_of_test(address, extracted_tb)[:2]
-                        writeln(' ' * len(kind) + '  $EDITOR +%s %s' %
-                                (line, human_path(src(file), self._cwd)))
+                        file, line = frame_of_test(address,
+                                                   exception_type,
+                                                   exception_value,
+                                                   extracted_tb)[:2]
+                        writeln(' ' * len(kind) + '  %s +%s %s' %
+                                (os.environ.get('EDITOR', 'vi'), line,
+                                 human_path(src(file), self._cwd)))
 
                     write(self._codes['sgr0'])  # end bold
 
